@@ -1,7 +1,6 @@
-from fontTools.misc.py23 import *
 import sys
 from fontTools.subset import main
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main())
